@@ -1,5 +1,5 @@
 /*
- * Copyright 2013-2014 Canonical Ltd.
+ * Copyright 2013-2015 Canonical Ltd.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of version 3 of the GNU Lesser General Public
@@ -129,6 +129,13 @@ DownloadImpl::DownloadImpl(const QDBusConnection& conn,
             "Could not connect to signal &DownloadInterface::authError");
     }
 
+    connected = connect(_dbusInterface, &DownloadInterface::hashError,
+        this, &DownloadImpl::onHashError);
+    if (!connected) {
+        Logger::log(Logger::Critical,
+            "Could not connect to signal &DownloadInterface::authError");
+    }
+
     connected = connect(_propertiesInterface, &PropertiesInterface::PropertiesChanged,
         this, &DownloadImpl::onPropertiesChanged);
     if (!connected) {
@@ -442,6 +449,12 @@ DownloadImpl::onAuthError(AuthErrorStruct errStruct) {
     setLastError(err);
 }
 
+void
+DownloadImpl::onHashError(HashErrorStruct errStruct) {
+    auto err = new HashError(errStruct, this);
+    setLastError(err);
+}
+
 void
 DownloadImpl::onPropertiesChanged(const QString& interfaceName,
                                   const QVariantMap& changedProperties,
